@@ -172,9 +172,9 @@ renderScatter <- function(div_id, data,
 
                         sep="")
 
-  to_eval <- paste("output$", div_id ," <- renderUI({fluidPage(tags$script(\"",
+  to_eval <- paste("output$", div_id ," <- renderUI({tags$script(\"",
                    js_statement,
-                   "\"))})",
+                   "\")})",
                    sep="")
 
   if(running_in_shiny == TRUE){
